==> colord-kde_0.5.0.orig.tar.xz: colord-kde-0.5.0/colord-kded/XEventHandler.h <==
/***************************************************************************
 *   Copyright (C) 2012 by Daniel Nicoletti <dantti12@gmail.com>           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; see the file COPYING. If not, write to       *
 *   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,  *
 *   Boston, MA 02110-1301, USA.                                           *
 ***************************************************************************/

#ifndef XEVENTHANDLER_H
#define XEVENTHANDLER_H

#include <QAbstractNativeEventFilter>
#include <QObject>

class Q_DECL_EXPORT XEventHandler : public QObject, public QAbstractNativeEventFilter
{
    Q_OBJECT
public:
    XEventHandler(int randrBase);

signals:
    void outputChanged();

protected:
    bool nativeEventFilter(const QByteArray &eventType, void *message, long int*) Q_DECL_OVERRIDE;

private:
    int m_randrBase;
};

#endif // XEVENTHANDLER_H

==> colord-kde-23.08.4.tar.xz: colord-kde-23.08.4/colord-kded/XEventHandler.h <==
/***************************************************************************
 *   Copyright (C) 2012 by Daniel Nicoletti <dantti12@gmail.com>           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; see the file COPYING. If not, write to       *
 *   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,  *
 *   Boston, MA 02110-1301, USA.                                           *
 ***************************************************************************/

#pragma once

#include <QAbstractNativeEventFilter>
#include <QObject>

class Q_DECL_EXPORT XEventHandler : public QObject, public QAbstractNativeEventFilter
{
    Q_OBJECT
public:
    XEventHandler(int randrBase);

Q_SIGNALS:
    void outputChanged();

protected:
#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
    bool nativeEventFilter(const QByteArray &eventType, void *message, long int *result) override;
#else
    bool nativeEventFilter(const QByteArray &eventType, void *message, qintptr *result) override;
#endif

private:
    int m_randrBase;
};
